@@ -210,17 +210,6 @@ namespace DDM {
         server->activateUser(user);
     }
 
-    void Display::activateUser(const QString &user) {
-        for (auto auth : m_auths) {
-            if (auth->user() == user) {
-                QString ttyString = VirtualTerminal::path(auth->tty());
-                int vtFd = open(qPrintable(ttyString), O_RDWR | O_NOCTTY);
-                qDebug() << user << " ioctl " << ioctl(vtFd, VT_ACTIVATE, auth->tty());
-                break;
-            }
-        }
-    }
-
     bool Display::start() {
         return m_started || m_displayServer->start();
     }
@@ -587,10 +576,16 @@ namespace DDM {
                 stateConfig.Last.Session.setDefault();
             stateConfig.save();
 
-            if (m_socket) {
-                emit loginSucceeded(m_socket, user);
-                daemonApp->displayManager()->setLastSession(auth->sessionId());
+            if (m_displayServerType == DisplayServerType::SingleCompositerServerType) {
+                auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
+                server->onLoginSucceeded(user);
+            } else {
+                if (m_socket) {
+                    emit loginSucceeded(m_socket, user);
+                    daemonApp->displayManager()->setLastSession(auth->sessionId());
+                }
             }
+
         }
         m_socket = nullptr;
     }
@@ -613,8 +608,14 @@ namespace DDM {
             return;
 
         m_socketServer->informationMessage(m_socket, message);
-        if (error == Auth::ERROR_AUTHENTICATION)
-            emit loginFailed(m_socket, auth->user());
+        if (error == Auth::ERROR_AUTHENTICATION) {
+            if (m_displayServerType == DisplayServerType::SingleCompositerServerType) {
+                auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
+                server->onLoginFailed(auth->user());
+            } else {
+                emit loginFailed(m_socket, auth->user());
+            }
+        }
     }
 
     void Display::slotHelperFinished(Auth::HelperExitStatus status) {
@@ -630,14 +631,14 @@ namespace DDM {
 
         if(!auth->identifyOnly()) {
             daemonApp->displayManager()->RemoveSession(auth->sessionId());
+            if (m_displayServerType == DisplayServerType::SingleCompositerServerType) {
+                auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
+                // TODO: switch to greeter
+                server->activateUser("dde");
+                return;
+            }
         }
 
-        if (m_displayServerType == DisplayServerType::SingleCompositerServerType) {
-            auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
-            // TODO: switch to greeter
-            server->activateUser("dde");
-            return;
-        }
         if (status != Auth::HELPER_AUTH_ERROR && m_displayServerType != DisplayServerType::SingleCompositerServerType)
             stop();
     }
